@@ -28,10 +28,10 @@ class Plot3dAssistant : public Cantor::Assistant
   Q_OBJECT
   public:
     Plot3dAssistant( QObject* parent, QList<QVariant> args );
-    ~Plot3dAssistant() override;
+    ~Plot3dAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    void initActions() override;
+    QStringList run(QWidget* parentt) override;
 };
 
 #endif /* _PLOT3DASSISTANT_H */
